Request

Struct Request 

pub struct Request {
    pub header: Header,
    pub body: Body,
}
Handle for accessing and mutating the current HTTP request.

Fields

header: Header

Handle for accessing and mutating request headers.

body: Body

Handle for reading or writing the request body.

Implementations

Source

impl Request

pub fn source_addr(&self) -> Bytes

Return the client source address (ip:port) as raw bytes.

Example
  • IPv6 b“[fe80::90f4:16ff:fee0:24b3%enp5s0]:41236“
  • IPv4 b“1.1.1.1:12345“

Supported are both IPv4 and IPv6

Note

A host who fails to get the remote address will trap (aka panic, “unreachable” instruction).

Examples found in repository?
examples/info.rs (line 18)
17    fn handle_request(&self, request: &Request, _response: &Response) -> (bool, i32) {
18        info!("Request: {} {} {} {}", request.method(), request.version(), request.uri(), request.source_addr());
19        for (name, values) in request.header.entries_iter() {
20            let values = values.iter().map(|v| format!("{v}")).collect::<Vec<_>>().join(", ");
21            info!("Header: {} [{}]", name, values);
22        }
23        info!("Body: {}", request.body.read());
24        (true, 0)
25    }
pub fn version(&self) -> Bytes

Return the HTTP protocol version (for example, HTTP/1.1).

Examples found in repository?
examples/info.rs (line 18)
17    fn handle_request(&self, request: &Request, _response: &Response) -> (bool, i32) {
18        info!("Request: {} {} {} {}", request.method(), request.version(), request.uri(), request.source_addr());
19        for (name, values) in request.header.entries_iter() {
20            let values = values.iter().map(|v| format!("{v}")).collect::<Vec<_>>().join(", ");
21            info!("Header: {} [{}]", name, values);
22        }
23        info!("Body: {}", request.body.read());
24        (true, 0)
25    }
pub fn method(&self) -> Bytes

Return the request method (for example, GET or POST).

Examples found in repository?
examples/info.rs (line 18)
17    fn handle_request(&self, request: &Request, _response: &Response) -> (bool, i32) {
18        info!("Request: {} {} {} {}", request.method(), request.version(), request.uri(), request.source_addr());
19        for (name, values) in request.header.entries_iter() {
20            let values = values.iter().map(|v| format!("{v}")).collect::<Vec<_>>().join(", ");
21            info!("Header: {} [{}]", name, values);
22        }
23        info!("Body: {}", request.body.read());
24        (true, 0)
25    }
pub fn set_method(&self, method: &[u8])

Replace the request method with the provided bytes.

pub fn uri(&self) -> Bytes

Return the request URI as raw bytes.

Examples found in repository?
examples/info.rs (line 18)
17    fn handle_request(&self, request: &Request, _response: &Response) -> (bool, i32) {
18        info!("Request: {} {} {} {}", request.method(), request.version(), request.uri(), request.source_addr());
19        for (name, values) in request.header.entries_iter() {
20            let values = values.iter().map(|v| format!("{v}")).collect::<Vec<_>>().join(", ");
21            info!("Header: {} [{}]", name, values);
22        }
23        info!("Body: {}", request.body.read());
24        (true, 0)
25    }
pub fn set_uri(&self, uri: &[u8])

Replace the request URI with the provided bytes.

pub fn header(&self) -> &Header

👎Deprecated since 0.11.2:

use the header field directly instead

Return a handle for accessing and mutating request headers.

pub fn body(&self) -> &Body

👎Deprecated since 0.11.2:

use the body field directly instead

Return a handle for reading or writing the request body.