HostLogger

Struct HostLogger 

pub struct HostLogger;
Logger implementation that forwards records to the host.

This integrates the Rust log crate with the http-wasm guest runtime’s logging system. It provides logging for plugin authors via standard macros (log::info!, log::warn!, etc.).

Implementations

Source

impl HostLogger

pub fn init() -> Result<(), SetLoggerError>

Initialize the host-backed logger with the default Info level.

This is a convenience function for [init_with_level] using Level::Info.

Examples found in repository?
examples/info.rs (line 33)
32fn main() {
33    let _ = HostLogger::init();
34    admin::enable(feature::BufferRequest | feature::BufferResponse);
35    let plugin = Plugin {};
36    register(plugin);
37}
pub fn init_with_level(level: Level) -> Result<(), SetLoggerError>

Initialize the host-backed logger with a specific maximum level.

This registers a HostLogger implementation for forwarding log records to the http-wasm host.