pub struct HostLogger;Expand description
Logger implementation that forwards records to the host.
This integrates the Rust log crate with the http-wasm guest runtime’s logging system.
It provides logging for plugin authors via standard macros (log::info!, log::warn!, etc.).
Implementations
Sourceimpl HostLogger
impl HostLogger
Sourcepub fn init() -> Result<(), SetLoggerError>
pub fn init() -> Result<(), SetLoggerError>
Initialize the host-backed logger with the default Info level.
This is a convenience function for [init_with_level] using Level::Info.
Sourcepub fn init_with_level(level: Level) -> Result<(), SetLoggerError>
pub fn init_with_level(level: Level) -> Result<(), SetLoggerError>
Initialize the host-backed logger with a specific maximum level.
This registers a HostLogger implementation for forwarding log records to the http-wasm host.